# Ververser Example 5: Mouse and Keyboard

This is just an example that illustrates how mouse and keyboard can be used. 
These are just some convenience classes you probably want to use when creating interactive applications using ververser.